@@ -1,3 +1,9 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
 import numpy as np
 
 
@@ -12,6 +18,10 @@ from hub.compute import transform
 from hub.log import logger
 import traceback
 from hub.exceptions import DaskModuleNotInstalledException, HubDatasetNotFoundException
+from hub.report import hub_reporter, hub_tags
+
+
+hub_reporter.system_report(tags=hub_tags)
 
 
 def local_mode():
