@@ -1,6 +1,14 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
+import os
+from hub.store.store import get_fs_and_path
 import numpy as np
 import sys
-from hub.exceptions import ModuleNotInstalledException
+from hub.exceptions import ModuleNotInstalledException, DirectoryNotEmptyException
 
 
 def slice_split(slice_):
@@ -70,7 +78,19 @@ def slice_extract_info(slice_, num):
     return num, offset
 
 
-def create_numpy_dict(dataset, index):
+def create_numpy_dict(dataset, index, label_name=False):
+    """Creates a list of dictionaries with the values from the tensorview objects in the dataset schema.
+
+    Parameters
+    ----------
+    dataset: hub.api.dataset.Dataset object
+        The dataset whose TensorView objects are being used.
+    index: int
+        The index of the dataset record that is being used.
+    label_name: bool, optional
+        If the TensorView object is of the ClassLabel type, setting this to True would retrieve the label names
+        instead of the label encoded integers, otherwise this parameter is ignored.
+    """
     numpy_dict = {}
     for path in dataset._tensors.keys():
         d = numpy_dict
@@ -79,7 +99,7 @@ def create_numpy_dict(dataset, index):
             if subpath not in d:
                 d[subpath] = {}
             d = d[subpath]
-        d[split[-1]] = dataset[path, index].numpy()
+        d[split[-1]] = dataset[path, index].numpy(label_name=label_name)
     return numpy_dict
 
 
@@ -139,3 +159,34 @@ def str_to_int(assign_value, tokenizer):
         ):
             assign_value = [np.array([ord(ch) for ch in item]) for item in assign_value]
     return assign_value
+
+
+def _copy_helper(
+    dst_url: str, token=None, fs=None, public=True, src_url=None, src_fs=None
+):
+    """Helper function for Dataset.copy"""
+    src_url = src_fs.expand_path(src_url)[0]
+    dst_url = dst_url[:-1] if dst_url.endswith("/") else dst_url
+    dst_fs, dst_url = (
+        (fs, dst_url) if fs else get_fs_and_path(dst_url, token=token, public=public)
+    )
+    if dst_fs.exists(dst_url) and dst_fs.ls(dst_url):
+        raise DirectoryNotEmptyException(dst_url)
+    for path in src_fs.ls(src_url, refresh=True):
+        dst_full_path = dst_url + path[len(src_url) :]
+        dst_folder_path, dst_file = os.path.split(dst_full_path)
+        if src_fs.isfile(path):
+            if not dst_fs.exists(dst_folder_path):
+                dst_fs.mkdir(dst_folder_path)
+            content = src_fs.cat_file(path)
+            dst_fs.pipe_file(dst_full_path, content)
+        else:
+            _copy_helper(
+                dst_full_path,
+                token=token,
+                fs=dst_fs,
+                public=public,
+                src_url=path,
+                src_fs=src_fs,
+            )
+    return dst_url
