@@ -1,3 +1,9 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
 import sys
 from hub import Dataset
 from hub.api.datasetview import DatasetView
@@ -50,8 +56,8 @@ class RayTransform(Transform):
         Remote wrapper for user defined function
         """
 
-        if isinstance(_ds, Dataset) or isinstance(_ds, DatasetView):
-            _ds.squeeze_dim = False
+        if isinstance(_ds, (Dataset, DatasetView)) and isinstance(_ds.indexes, int):
+            _ds.indexes = [_ds.indexes]
 
         item = _ds[index]
         if isinstance(item, DatasetView) or isinstance(item, Dataset):
