@@ -1,3 +1,9 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
 import zarr
 import numpy as np
 import math
@@ -6,14 +12,13 @@ from hub.api.dataset import Dataset
 from tqdm import tqdm
 from collections.abc import MutableMapping
 from hub.utils import batchify
-from hub.api.dataset_utils import get_value, slice_extract_info, slice_split, str_to_int
+from hub.api.dataset_utils import get_value, slice_split, str_to_int, slice_extract_info
 import collections.abc as abc
 from hub.api.datasetview import DatasetView
 from pathos.pools import ProcessPool, ThreadPool
-from hub.schema import Primitive
 from hub.schema.sequence import Sequence
 from hub.schema.features import featurify
-import posixpath
+import os
 from hub.defaults import OBJECT_CHUNK
 
 
@@ -113,19 +118,12 @@ class Transform:
         slice_ = list(slice_)
         subpath, slice_list = slice_split(slice_)
 
-        if len(slice_list) == 0:
-            slice_list = [slice(None, None, None)]
+        slice_list = slice_list or [slice(None, None, None)]
 
         num, ofs = slice_extract_info(slice_list[0], self.shape[0])
+        ds_view = self._ds[slice_list[0]]
 
-        ds_view = DatasetView(
-            dataset=self._ds,
-            num_samples=num,
-            offset=ofs,
-            squeeze_dim=isinstance(slice_list[0], int),
-        )
-
-        path = posixpath.expanduser("~/.activeloop/tmparray")
+        path = os.path.expanduser("~/.activeloop/tmparray")
         new_ds = self.store(path, length=num, ds=ds_view, progressbar=False)
 
         index = 1 if len(slice_) > 1 else 0
@@ -159,24 +157,6 @@ class Transform:
                 items.append((new_key, v))
         return dict(items)
 
-    @classmethod
-    def _flatten(cls, items, schema):
-        """
-        Takes a dictionary or list of dictionary.
-        Returns a dictionary of concatenated values.
-        Dictionary follows schema.
-        """
-        final_item = {}
-        for item in cls._unwrap(items):
-            item = cls._flatten_dict(item, schema=schema)
-
-            for k, v in item.items():
-                if k in final_item:
-                    final_item[k].append(v)
-                else:
-                    final_item[k] = [v]
-        return final_item
-
     @classmethod
     def dtype_from_path(cls, path, schema):
         """
@@ -297,12 +277,15 @@ class Transform:
             # Disable dynamic arrays
             ds.dataset._tensors[f"/{key}"].disable_dynamicness()
             list(self.map(upload_chunk, index_batched_values))
+            offset = ds.indexes[
+                0
+            ]  # here ds.indexes will always be a contiguous list as obtained after slicing
 
             # Enable and rewrite shapes
             if ds.dataset._tensors[f"/{key}"].is_dynamic:
                 ds.dataset._tensors[f"/{key}"].enable_dynamicness()
                 ds.dataset._tensors[f"/{key}"].set_shape(
-                    [slice(ds.offset, ds.offset + len(value))], value
+                    [slice(offset, offset + len(value))], value
                 )
 
         ds.commit()
@@ -447,7 +430,7 @@ class Transform:
             total=length,
             unit_scale=True,
             unit=" items",
-            desc="Computing the transormation",
+            desc=f"Computing the transformation in chunks of size {n_samples}",
         ) as pbar:
             for ds_in_shard in batchify_generator(ds_in, n_samples):
                 n_results = self.store_shard(ds_in_shard, ds_out, start, token=token)
