@@ -1,3 +1,9 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
 import os
 
 curr_path = os.path.dirname(os.path.abspath(__file__))
@@ -23,3 +29,8 @@ CREATE_DATASET_SUFFIX = "/api/dataset/create"
 UPDATE_STATE_SUFFIX = "/api/dataset/state"
 DATASET_SUFFIX = "/api/dataset/"
 DISTRIBUTED = True
+
+# Reporting-related configuration
+HUMBUG_TOKEN = "63423cd9-0951-4525-aeb3-257bbed6c6f5"
+HUMBUG_KB_ID = "5e264dc7-72bf-44bb-9b0b-220b7381ad72"
+REPORT_CONSENT_FILE_PATH = os.path.expanduser("~/.activeloop/reporting_config.json")
