@@ -1,67 +1,79 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
 from click import ClickException
 
+from hub.report import (
+    hub_reporter,
+    ExceptionWithReporting,
+    hub_tags,
+)
 
-class OutOfBoundsError(Exception):
+
+class OutOfBoundsError(ExceptionWithReporting):
     """Raised upon finding a missing chunk."""
 
     pass
 
 
-class AlignmentError(Exception):
+class AlignmentError(ExceptionWithReporting):
     """Raised when there is an Alignment error."""
 
     pass
 
 
-class IncompatibleShapes(Exception):
+class IncompatibleShapes(ExceptionWithReporting):
     """Shapes do not match"""
 
     pass
 
 
-class IncompatibleBroadcasting(Exception):
+class IncompatibleBroadcasting(ExceptionWithReporting):
     """Broadcasting issue"""
 
     pass
 
 
-class IncompatibleTypes(Exception):
+class IncompatibleTypes(ExceptionWithReporting):
     """Types can not cast"""
 
     pass
 
 
-class WrongTypeError(Exception):
+class WrongTypeError(ExceptionWithReporting):
     """Types is not supported"""
 
     pass
 
 
-class NotAuthorized(Exception):
+class NotAuthorized(ExceptionWithReporting):
     """Types is not supported"""
 
     pass
 
 
-class NotFound(Exception):
+class NotFound(ExceptionWithReporting):
     """When Info could not be found for array"""
 
     pass
 
 
-class FileSystemException(Exception):
+class FileSystemException(ExceptionWithReporting):
     """Error working with local file system"""
 
     pass
 
 
-class S3Exception(Exception):
+class S3Exception(ExceptionWithReporting):
     """Error working with AWS"""
 
     pass
 
 
-class S3CredsParseException(Exception):
+class S3CredsParseException(ExceptionWithReporting):
     """Can't parse AWS creds"""
 
     pass
@@ -75,6 +87,7 @@ class HubException(ClickException):
 class AuthenticationException(HubException):
     def __init__(self, message="Authentication failed. Please login again."):
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class AuthorizationException(HubException):
@@ -84,6 +97,7 @@ class AuthorizationException(HubException):
         except (KeyError, AttributeError):
             message = "You are not authorized to access this resource on Snark AI."
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class NotFoundException(HubException):
@@ -92,6 +106,7 @@ class NotFoundException(HubException):
         message="The resource you are looking for was not found. Check if the name or id is correct.",
     ):
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class BadRequestException(HubException):
@@ -105,6 +120,7 @@ class BadRequestException(HubException):
                 response.content
             )
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class OverLimitException(HubException):
@@ -113,85 +129,107 @@ class OverLimitException(HubException):
         message="You are over the allowed limits for this operation. Consider upgrading your account.",
     ):
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class ServerException(HubException):
     def __init__(self, message="Internal Snark AI server error."):
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class BadGatewayException(HubException):
     def __init__(self, message="Invalid response from Snark AI server."):
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class GatewayTimeoutException(HubException):
     def __init__(self, message="Snark AI server took too long to respond."):
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class WaitTimeoutException(HubException):
     def __init__(self, message="Timeout waiting for server state update."):
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class LockedException(HubException):
     def __init__(self, message="Resource locked."):
         super().__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class HubDatasetNotFoundException(HubException):
     def __init__(self, response):
         message = f"The dataset with tag {response} was not found"
         super(HubDatasetNotFoundException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class PermissionException(HubException):
     def __init__(self, response):
         message = f"No permision to store the dataset at {response}"
         super(PermissionException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class ShapeArgumentNotFoundException(HubException):
     def __init__(self):
         message = "Parameter 'shape' should be provided for Dataset creation."
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
+
+
+class DirectoryNotEmptyException(HubException):
+    def __init__(self, dst_url):
+        message = f"The destination url {dst_url} for copying dataset is not empty. Delete the directory manually or use Dataset.delete if it's a Hub dataset"
+        super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class SchemaArgumentNotFoundException(HubException):
     def __init__(self):
         message = "Parameter 'schema' should be provided for Dataset creation."
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class ValueShapeError(HubException):
     def __init__(self, correct_shape, wrong_shape):
         message = f"parameter 'value': expected array with shape {correct_shape}, got {wrong_shape}"
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class NoneValueException(HubException):
     def __init__(self, param):
         message = f"Parameter '{param}' should be provided"
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class ShapeLengthException(HubException):
     def __init__(self):
         message = "Parameter 'shape' should be a tuple of length 1"
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class ModuleNotInstalledException(HubException):
     def __init__(self, module_name):
         message = f"Module '{module_name}' should be installed to convert the Dataset to the {module_name} format"
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class DaskModuleNotInstalledException(HubException):
     def __init__(self, message=""):
         message = "Dask has been deprecated and made optional. Older versions of 0.x hub datasets require loading dask. Please install it: pip install 'dask[complete]>=2.30'"
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class WrongUsernameException(HubException):
@@ -201,6 +239,7 @@ class WrongUsernameException(HubException):
             "or make sure that the username provided in the url matches the one used during login or ."
         )
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class NotHubDatasetToOverwriteException(HubException):
@@ -213,6 +252,7 @@ class NotHubDatasetToOverwriteException(HubException):
             "In that case feel free to create an issue in here https://github.com/activeloopai/Hub"
         )
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class NotHubDatasetToAppendException(HubException):
@@ -222,12 +262,14 @@ class NotHubDatasetToAppendException(HubException):
             "The provided directory is not empty and doesn't contain information about any Hub Dataset "
         )
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class DynamicTensorNotFoundException(HubException):
     def __init__(self):
         message = "Unable to find dynamic tensor"
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class DynamicTensorShapeException(HubException):
@@ -241,23 +283,19 @@ class DynamicTensorShapeException(HubException):
         else:
             message = "Wrong 'shape' or 'max_shape' values"
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
 class NotIterable(HubException):
     def __init__(self):
         message = "First argument to transform function should be iterable"
         super(HubException, self).__init__(message=message)
+        hub_reporter.error_report(self, tags=hub_tags)
 
 
-class AdvancedSlicingNotSupported(HubException):
-    def __init__(self):
-        message = "Advanced slicing is not supported, only support index"
-        super(HubException, self).__init__(message=message)
-
-
-class NotZarrFolderException(Exception):
+class NotZarrFolderException(ExceptionWithReporting):
     pass
 
 
-class StorageTensorNotFoundException(Exception):
+class StorageTensorNotFoundException(ExceptionWithReporting):
     pass
