@@ -1,3 +1,9 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
 # from typing import Tuple
 
 from hub.schema.features import Tensor
@@ -7,7 +13,7 @@ class BBox(Tensor):
     """| HubSchema` for a normalized bounding box.
 
     Output: Tensor of type `float32` and shape `[4,]` which contains the
-    normalized coordinates of the bounding box `[ymin, xmin, ymax, xmax]`
+    normalized coordinates of the bounding box `[xmin, ymin, xmax, ymax]`
     """
 
     def __init__(self, dtype="float64", chunks=None, compressor="lz4"):
@@ -27,10 +33,6 @@ class BBox(Tensor):
             shape=(4,), dtype=dtype, chunks=chunks, compressor=compressor
         )
 
-    def get_attr_dict(self):
-        """Return class attributes."""
-        return self.__dict__
-
     def __str__(self):
         out = super().__str__()
         out = "BBox" + out[6:]
