@@ -1,3 +1,9 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
 from typing import List
 from hub.schema.features import Tensor
 
@@ -82,8 +88,8 @@ class ClassLabel(Tensor):
             self._names = names
             self.names = names
         else:
-            self._names = names
-            self.names = _load_names_from_file(names_file)
+            self._names = _load_names_from_file(names_file)
+            self.names = self._names
 
     @property
     def names(self):
@@ -132,17 +138,12 @@ class ClassLabel(Tensor):
 
     def int2str(self, int_value: int):
         """Conversion integer => class name string."""
-        if self._int2str:
-            return self._int2str[int_value]
+        return self.names[int_value]
 
     @property
     def num_classes(self):
         return self._num_classes
 
-    def get_attr_dict(self):
-        """Return class attributes."""
-        return self.__dict__
-
     def __str__(self):
         out = super().__str__()
         out = "ClassLabel" + out[6:-1]
