@@ -1,3 +1,9 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
 from typing import Tuple
 
 import numpy as np
@@ -12,7 +18,7 @@ class Text(Tensor):
         self,
         shape: Tuple[int, ...] = (None,),
         dtype="int64",
-        max_shape: Tuple[int, ...] = (None,),
+        max_shape: Tuple[int, ...] = None,
         chunks=None,
         compressor="lz4",
     ):
@@ -47,10 +53,6 @@ class Text(Tensor):
         dtype = str(np.dtype(dtype))
         self.dtype = dtype
 
-    def get_attr_dict(self):
-        """Return class attributes."""
-        return self.__dict__
-
     def __str__(self):
         out = super().__str__()
         out = "Text" + out[6:]
