@@ -1,3 +1,10 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
+from hub.utils import _tuple_product
 from hub.numcodecs import PngCodec
 import math
 
@@ -69,7 +76,7 @@ class ShapeDetector:
 
     def _get_chunks(self, shape, max_shape, chunks, dtype, chunksize):
         if chunks is None:
-            prod = self._tuple_product(max_shape[1:])
+            prod = _tuple_product(max_shape[1:])
             if dtype == "object":
                 return (self._object_chunking,) + max_shape[1:]
             if prod <= 2 * chunksize:
@@ -96,16 +103,18 @@ class ShapeDetector:
             if len(chunks) == 1:
                 return self._get_chunks(shape, max_shape, chunks[0], dtype, chunksize)
             else:
-                assert len(chunks) == len(shape)
-                assert chunks[0] == 1
+                if len(chunks) != len(shape):
+                    raise Exception(
+                        "If you want a multidimensional chunk, the number of dimensions should match with that of the shape parameter."
+                        f" Number of chunk dimensions received={len(chunks)}, number of chunk dimensions required={len(shape)}"
+                    )
+                if chunks[0] != 1:
+                    raise Exception(
+                        "If you want multiple samples in the chunk, then specify only the number in the chunk, rest of the dimensions "
+                        f"should be omitted. In this case use 'chunks={chunks[0]}'"
+                    )
                 return chunks
 
-    def _tuple_product(self, tuple_):
-        res = 1
-        for t in tuple_:
-            res *= t
-        return res
-
     def _determine_chunksizes(self, max_shape, dtype, chunksize):
         """
         Autochunking of tensors
