@@ -1,3 +1,9 @@
+"""
+License:
+This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
+If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""
+
 from math import gcd
 import time
 from collections import abc
@@ -49,9 +55,7 @@ def azure_creds_exist():
     import os
 
     env = os.getenv("ACCOUNT_KEY")
-    if env is not None:
-        return True
-    return False
+    return env is not None
 
 
 def hub_creds_exist():
@@ -60,9 +64,17 @@ def hub_creds_exist():
     import os
 
     env = os.getenv("ACTIVELOOP_HUB_PASSWORD")
-    if env is not None:
-        return True
-    return False
+    return env is not None
+
+
+def minio_creds_exist():
+    """Checks if credentials exists"""
+
+    import os
+
+    env1 = os.getenv("ACTIVELOOP_MINIO_KEY")
+    env2 = os.getenv("ACTIVELOOP_MINIO_SECRET_ACCESS_KEY")
+    return env1 is not None and env2 is not None
 
 
 def pytorch_loaded():
@@ -158,6 +170,13 @@ def batchify(iterable, n=1):
     return batches
 
 
+def _tuple_product(tuple_):
+    res = 1
+    for t in tuple_:
+        res *= t
+    return res
+
+
 class Timer:
     def __init__(self, text):
         self._text = text
